@@ -50,6 +50,7 @@ class AnalysisSTEAM:
         self.list_viewers = {}  # this dictionary will be populated with Viewer objects and their names
         self.list_metrics = {}  # this dictionary will be populated with calculated metrics
         self.verbose = verbose
+        self.overall_parameter = None  # float representing the overall outcome of a simulation for parsims
 
         # Read working folders and set them up
         self._set_up_working_folders()
@@ -250,7 +251,8 @@ class AnalysisSTEAM:
         # Build simulation file
         if step.simulation_number:
             if 'FiQuS' in step.software:
-                self.setup_sim_FiQuS(simulation_name=step.simulation_name, simulation_type=step.type, sim_number=step.simulation_number, magnet_name=BM.model_data.GeneralParameters.magnet_name, magnet_type=BM.model_data.GeneralParameters.magnet_type)
+                self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=step.simulation_number, magnet_type=BM.model_data.GeneralParameters.magnet_type)
+                # note above magnet_type is specified only for the step_make_model to make setup_sim_FiQuS copy additional files needed for the multipole magnet
             if 'LEDET' in step.software:
                 flag_yaml = True  # Hard-coded for the moment
                 self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=step.simulation_number, flag_yaml=flag_yaml, flag_json=flag_json)
@@ -334,9 +336,8 @@ class AnalysisSTEAM:
             if len_simulation_numbers > 0:
                 simulation_number = step.simulation_numbers[v]
                 if 'FiQuS' in step.software:
-                    BM.buildFiQuS()
-                    #self.setup_sim_FiQuS(magnet_type=BM.model_data.GeneralParameters.magnet_type, simulation_name=step.simulation_name, model_name=step.model_name, simulation_type=step.type, sim_number=simulation_number)
-                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, simulation_type=step.type, sim_number=simulation_number, magnet_name=BM.model_data.GeneralParameters.magnet_name, magnet_type=BM.model_data.GeneralParameters.magnet_type)
+                    BM.buildFiQuS(simulation_name=f'{step.simulation_name}')
+                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=simulation_number)
                 if 'LEDET' in step.software:
                     flag_json = BM.flag_json
                     flag_yaml = True  # Hard-coded for the moment
@@ -579,7 +580,7 @@ class AnalysisSTEAM:
         if len_simulation_numbers > 0:
             for simulation_number in step.simulation_numbers:
                 if 'FiQuS' in step.software:
-                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, simulation_type=step.type, sim_number=simulation_number)
+                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=simulation_number, simulation_type=step.type)
                 if 'LEDET' in step.software:
                     flag_yaml = True  # Hard-coded for the moment
                     flag_json = False  # Hard-coded for the moment
@@ -764,36 +765,34 @@ class AnalysisSTEAM:
 
         return current_list_output_metrics
 
-    def setup_sim_FiQuS(self, simulation_name, simulation_type, sim_number, magnet_name=None, magnet_type=None):
+    def setup_sim_FiQuS(self, simulation_name, sim_number, magnet_type=None):
         """
         Set up a FiQuS simulation by copying the last file generated by BuilderModel to the output folder and to the
         local FiQuS working folder.
         The original file is then deleted.
         """
 
-
         # Add simulation number to the list
         self.list_sims.append(sim_number)
 
         # Make simulation folder
-        local_model_folder = os.path.join(self.settings.local_FiQuS_folder, simulation_name + '_' + str(sim_number))
+        local_model_folder = os.path.join(self.settings.local_FiQuS_folder, f'{simulation_name}_{str(sim_number)}')
         make_folder_if_not_existing(local_model_folder)
 
         # Copy simulation file
-        file_name_temp = os.path.join(self.output_path, magnet_name)
+        file_name_temp = os.path.join(self.output_path, f'{simulation_name}')
         yaml_temp = os.path.join(file_name_temp + '_FiQuS.yaml')
-        file_name_local = os.path.join(local_model_folder, simulation_name)
+        file_name_local = os.path.join(local_model_folder, f'{simulation_name}')
         yaml_local = os.path.join(file_name_local + '.yaml')
         shutil.copyfile(yaml_temp, yaml_local)
 
         if magnet_type == 'multipole':
-            if simulation_type == 'MakeModel':
-                geo_temp = os.path.join(file_name_temp + '_FiQuS.geom')
-                set_temp = os.path.join(file_name_temp + '_FiQuS.set')
-                geo_local = os.path.join(file_name_local + '.geom')
-                set_local = os.path.join(file_name_local + '.set')
-                shutil.copyfile(geo_temp, geo_local)
-                shutil.copyfile(set_temp, set_local)
+            geo_temp = os.path.join(file_name_temp + '_FiQuS.geom')
+            set_temp = os.path.join(file_name_temp + '_FiQuS.set')
+            geo_local = os.path.join(file_name_local + '.geom')
+            set_local = os.path.join(file_name_local + '.set')
+            shutil.copyfile(geo_temp, geo_local)
+            shutil.copyfile(set_temp, set_local)
 
         if self.verbose: print('Simulation files {} generated.'.format(file_name_temp))
         if self.verbose: print('Simulation files {} copied.'.format(file_name_local))
@@ -911,7 +910,7 @@ class AnalysisSTEAM:
         # print('Temporary file {} deleted.'.format(file_name_temp))
 
         local_XYCE_folder = Path(self.settings.local_XYCE_folder)
-        local_model_folder = str(Path(local_XYCE_folder / simulation_name).resolve())
+        local_model_folder = str(Path(local_XYCE_folder / simulation_name/ str(sim_number)).resolve())
         # Make circuit input folder
         make_folder_if_not_existing(local_model_folder, verbose=self.verbose)
 
@@ -977,7 +976,7 @@ class AnalysisSTEAM:
             local_analysis_folder = simulation_name + '_' + str(sim_number)
             dFiQuS = DriverFiQuS(FiQuS_path=self.settings.FiQuS_path, path_folder_FiQuS=self.settings.local_FiQuS_folder,
                                  path_folder_FiQuS_input=os.path.join(self.settings.local_FiQuS_folder, local_analysis_folder), verbose=verbose)
-            dFiQuS.run_FiQuS(sim_file_name=simulation_name, output_directory=local_analysis_folder)
+            self.overall_parameter = dFiQuS.run_FiQuS(sim_file_name=simulation_name, output_directory=local_analysis_folder)
         elif software == 'LEDET':
             dLEDET = DriverLEDET(path_exe=self.settings.LEDET_path, path_folder_LEDET=self.settings.local_LEDET_folder, verbose=verbose)
             dLEDET.run_LEDET(simulation_name, str(sim_number), simFileType=simFileType)
