@@ -7,7 +7,7 @@ import matplotlib.pyplot as plt
 import h5py
 
 from steam_sdk.analyses.AnalysisSTEAM import AnalysisSTEAM
-from steam_sdk.parsers.ParserYAML import yaml_to_dict
+from steam_sdk.parsers.ParserYAML import yaml_to_data
 from steam_sdk.utils.make_folder_if_not_existing import make_folder_if_not_existing
 from steam_sdk.utils.tic_toc import tic, toc
 from steam_sdk.utils.unique import unique
@@ -77,7 +77,7 @@ def analysis_short_circuit_LEDET_1(dict_inputs: Dict):
 
     # Read self-mutual inductance matrix and half-turn electrical order
     M = np.genfromtxt(path_file_inductance, dtype=float, delimiter=',', skip_header=1)
-    dict_LEDET = yaml_to_dict(path_file_reference_model_LEDET)
+    dict_LEDET = yaml_to_data(path_file_reference_model_LEDET)
     iContactAlongWidth_From = dict_LEDET['iContactAlongWidth_From']
     iContactAlongWidth_To = dict_LEDET['iContactAlongWidth_To']
     iContactAlongHeight_From = dict_LEDET['iContactAlongHeight_From']
