@@ -129,6 +129,8 @@ class BuilderModel:
                 for s in self.software:
                     if s == 'PSPICE': self.buildPSPICE()
                     elif s == 'XYCE': self.buildXYCE()
+                    else:
+                        raise Exception('Please specify software (PSPICE/XYCE).')
 
         ### Case of a conductor model
         elif self.case_model == 'conductor':
@@ -240,6 +242,8 @@ class BuilderModel:
                     Parser = ParserXYCE(self.circuit_data)
                     Parser.readFromYaml(self.file_model_data)
                     self.circuit_data = Parser.circuit_data
+                else:
+                    raise Exception('Please specify software (PSPICE/XYCE).')
         elif self.case_model == 'conductor':
             # Load yaml keys into DataModelConductor dataclass
             self.conductor_data = yaml_to_data(self.file_model_data, DataModelConductor)
@@ -272,9 +276,10 @@ class BuilderModel:
         self.roxie_data = roxie_parser.getData(dir_data=self.path_data, dir_cadata=self.path_cadata,
                                                dir_iron=self.path_iron)
 
-    def buildFiQuS(self):
+    def buildFiQuS(self, simulation_name=None):
         """
             Building a FiQuS model
+            :param simulation_name: This is used in analysis steam to change yaml name from magnet name to simulation name
         """
 
         builder_FiQuS = BuilderFiQuS(model_data=self.model_data, roxie_data=self.roxie_data,
@@ -282,7 +287,7 @@ class BuilderModel:
 
         # Write output files
         self.parser_FiQuS = ParserFiQuS(builder_FiQuS, verbose=self.verbose)
-        self.parser_FiQuS.writeFiQuS2yaml(output_path=self.output_path, append_str_to_magnet_name='_FiQuS')
+        self.parser_FiQuS.writeFiQuS2yaml(output_path=self.output_path, simulation_name=simulation_name, append_str_to_magnet_name='_FiQuS')
 
     def buildLEDET(self):
         """
