@@ -1,7 +1,5 @@
-from pydantic import BaseModel, PrivateAttr
-from typing import (Deque, Dict, FrozenSet, List, Optional, Sequence, Set, Tuple, Union, Type)
-
-import ruamel.yaml
+from pydantic import BaseModel
+from typing import (List, Union)
 
 from steam_sdk.data.DataConductor import Conductor
 
@@ -202,7 +200,7 @@ class FQPLs(BaseModel):  # Geometry related fqpls _inputs
     """
         Level 2: Class for the FQPLs parameters for protection
     """
-    enabled: bool = None  # are fqpls enabled
+    enabled: List[bool] = None  # list specifying which fqpl is enabled
     names: List[str] = None  # name to use in gmsh and getdp
     fndpls: List[int] = None  # fqpl number of divisions per length
     fwws: List[float] = None  # fqpl wire widths (assuming rectangular) for theta = 0 this is x dimension
@@ -216,6 +214,7 @@ class FQPLs(BaseModel):  # Geometry related fqpls _inputs
     currents: List[float] = None  # current in the wire
     sigmas: List[float] = None  # electrical conductivity
     mu_rs: List[float] = None  # relative permeability
+    th_conns_def: List[List] = None
 
 
 class QuenchProtection(BaseModel):
