@@ -13,7 +13,7 @@ class DataSettings(BaseModel):
     COSIM_path:          str = None  #
     Dakota_path:         str = None  #
     FiQuS_path:          str = None  #
-    FiQuS_GetDP_path:    str = None  # full path to CERN GetDP build executable
+    #FiQuS_GetDP_path:    str = None  # full path to CERN GetDP build executable
     LEDET_path:          str = None  #
     ProteCCT_path:       str = None  #
     PSPICE_path:         str = None  #
@@ -25,3 +25,4 @@ class DataSettings(BaseModel):
     local_LEDET_folder:  str = None  # full path to local LEDET folder
     local_PyBBQ_folder:  str = None  # full path to local PyBBQ folder
     local_PSPICE_folder: str = None  # full path to local PSPICE folder
+    local_XYCE_folder:   str = None  # full path to local PSPICE folder
