@@ -361,6 +361,8 @@ class ParserXYCE:
         :param verbose:
         :return:
         '''
+        current_path = Path(full_path_file_name).parent.resolve()
+
         # Title of the circuit
         row_title = [f'{self.circuit_data.GeneralParameters.circuit_name} \n']
 
@@ -388,7 +390,9 @@ class ParserXYCE:
             # Add global parameter entries
             for name, value in self.circuit_data.GlobalParameters.global_parameters.items():
                 if '#' in value:
-                    value.replace('#','')
+                    value = value.replace('#','')
+                if '#' in name:
+                    name = name.replace('#','')
                 rows_global_parameters.append(add_global_parameter(name, value))
 
         # Prepare initial conditions
@@ -399,7 +403,7 @@ class ParserXYCE:
             # Add initial condition entries
             for name, value in self.circuit_data.InitialConditions.initial_conditions.items():
                 if name[0].casefold()=='i':
-                    print('Initial condition for currents not supported in XYCE. Will be ignored.')
+                    if verbose: print('Initial condition for currents not supported in XYCE. Will be ignored.')
                     continue
                 rows_initial_conditions.append(add_initial_condition(name, value))
 
@@ -439,7 +443,7 @@ class ParserXYCE:
                 if name == None or nodes == None or value == None:
                     raise Exception('Netlist component in position #{} is of type {} and requires name, nodes, and value.'.format(s+1, type))
                 if verbose: print('Netlist entry {} in position #{} is treated as a stimulus-controlled component.'.format(name, s + 1))
-                rows_netlist.append(add_stimulus_controlled_component(name, nodes, value))
+                rows_netlist.append(add_stimulus_controlled_component(name, nodes, value, output_path = current_path))
             elif type == 'pulsed-source component':
                 if name == None or nodes == None or value == None:
                     raise Exception('Netlist component in position #{} is of type {} and requires name, nodes, and value.'.format(s+1, type))
@@ -594,7 +598,7 @@ class ParserXYCE:
             Copy additional files
         :return: Number of copied files
         '''
-        for file_to_copy in self.circuit_data.GeneralParameters.additional_files:
+        for file_to_copy in self.circuit_data.GeneralParameters.additional_files+self.circuit_data.Stimuli.stimulus_files:
             if not os.path.isabs(file_to_copy) and self.path_input:
                 # If the provided path is relative, use the path_input as the root folder (if available)
                 file_to_copy_relative = os.path.join(self.path_input, file_to_copy)
@@ -615,6 +619,11 @@ class ParserXYCE:
                 if verbose: print('Dir {} does not exist. Skipped.'.format(self.output_path))
                 continue
             if flag_translate and str(file_to_copy).endswith('.lib'):
+                ## TODO: Temporary fix, until merged libraries!
+                if 'converter' in str(file_to_copy):
+                    file_to_copy = list(file_to_copy)
+                    file_to_copy.insert(-4, '_XYCE')
+                    file_to_copy = ''.join(file_to_copy)
                 translate_library_PSPICE_2_XYCE(file_to_copy, file_to_write.replace('PSPICE','XYCE'))
             elif flag_translate and str(file_to_copy).endswith('.stl'):
                 # path_stl = str(Path(file_to_write+'/..').resolve())
@@ -695,10 +704,14 @@ def add_controlled_source_component(name: str, nodes: list, value: str):
     return formatted_text
 
 
-def add_stimulus_controlled_component(name: str, nodes: list, value: str):
+def add_stimulus_controlled_component(name: str, nodes: list, value: str, output_path = ''):
     ''' Format stimulus-controlled component netlist row '''
     str_nodes = " ".join(nodes)  # string with space-separated nodes
-    str_stimulus = 'PWL ' + value
+    if len(value.split(' '))==1:
+        output_path = str(output_path).replace(os.sep, '/')
+        str_stimulus = 'PWL FILE ' + output_path + '/Stimulus/' + value + '.csv'
+    else:
+        str_stimulus = 'PWL ' + value
     formatted_text = name + ' ' + str_nodes + ' ' + str_stimulus
     return formatted_text
 
@@ -824,27 +837,29 @@ def translate_library_PSPICE_2_XYCE(in_file_library: str, out_file_library: str,
         idx_start = []
         idx_end = []
         for i in range(len(lines)):
-            if lines[i].startswith('.subckt') and not flag_inSubckt and not flag_inModel:
+            if lines[i].casefold().startswith('.subckt') and not flag_inSubckt and not flag_inModel:
                 flag_inSubckt = 1
-                idx_start.append(i)
-            elif flag_inSubckt and lines[i].startswith('.ends'):
+                idx_start_s = i
+            elif flag_inSubckt and lines[i].casefold().startswith('.ends'):
                 flag_inSubckt = 0
                 idx_end.append(i)
-            if lines[i].startswith('.model') and not flag_inModel and not flag_inSubckt:
+                idx_start.append(idx_start_s)
+            if lines[i].casefold().startswith('.model') and not flag_inModel and not flag_inSubckt:
                 flag_inModel = 1
-                idx_start.append(i)
+                idx_start_m = i
             elif flag_inModel and not lines[i].startswith('+'):
                 flag_inModel = 0
                 idx_end.append(i)
+                idx_start.append(idx_start_m)
         if flag_inSubckt or flag_inModel:
             raise Exception("Couldn't find a .ends. Please check.")
         for i in range(len(idx_start)):
             test = lines[idx_start[i]:idx_end[i]+1]
             old_model = ''.join(lines[idx_start[i]:idx_end[i]+1])
-            new_model = translate_model_PSPICE_2_XYCE(old_model, output_path)
+            new_model, flag_Added = translate_model_PSPICE_2_XYCE(old_model, output_path)
             new_model = new_model.split('\n')
             new_model = [x+'\n' for x in new_model]
-            lines[idx_start[i]:idx_end[i]+1] = new_model[:-1]
+            lines[idx_start[i]:idx_end[i]+1+flag_Added] = new_model[:-1]
 
         with open(out_file_library, 'w') as f:
             for line in lines:
@@ -868,6 +883,7 @@ def translate_model_PSPICE_2_XYCE(model: str, output_path: str = ''):
     list_possible_ABM = ['e','f','g','h','b']
 
     flag_inModel = False
+    flag_Added = 0
 
     for i in range(len(model_split)):
         line = model_split[i].replace('\t',' ')
@@ -915,6 +931,11 @@ def translate_model_PSPICE_2_XYCE(model: str, output_path: str = ''):
                     else:
                         str_val = str_val + val_split[j]
                 value = str_val
+            else:
+                line_split = line.split(' ')
+                value = line_split[-1]
+                line_split = [x+' ' for x in line_split]
+
 
             line = ''.join(line_split[:-1])
             line_split = line.split(' ')
@@ -929,6 +950,7 @@ def translate_model_PSPICE_2_XYCE(model: str, output_path: str = ''):
             if line.replace('\n', '').replace('\t', '').replace(' ', '')[-1].casefold() == 'd':
                 # Diode models in XYCE need to be specified to be Level = 2 (PSPICE implementation)
                 line = line + '\n+ LEVEL = 2'
+                flag_Added = flag_Added +1
         elif line[0].casefold() in list_possible_components:
             # Nodes in XYCE are not allowed to be hold in brackets
             if '{' in line:
@@ -943,7 +965,7 @@ def translate_model_PSPICE_2_XYCE(model: str, output_path: str = ''):
             line = ' '.join(line_split)
         model_split[i] = line
     model = '\n'.join(model_split)
-    return model
+    return model, flag_Added
 
 
 def translate_stimulus_line(line: str, origin_stl: str = ''):
